@@ -3,10 +3,10 @@ use std::time::Duration;
 use crate::channel::{Receiver, RecvError, RecvTimeoutError, TryRecvError, CHANNEL_SIZE_PREFIX};
 use crate::metrics::metric::{Counter, Gauge};
 
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct ChannelReceiver<T>
 where
-    T: Clone,
+    T: Sync + Send,
 {
     name: String,
     guava_size_name: String,
@@ -19,7 +19,7 @@ where
 
 impl<T> ChannelReceiver<T>
 where
-    T: Clone,
+    T: Sync + Send,
 {
     pub fn new(name: &str, receiver: Receiver<T>, size: Gauge, drain_counter: Counter) -> Self {
         ChannelReceiver {
