@@ -21,8 +21,8 @@ use crate::runtime::coordinator::heart_beat_manager::HeartbeatResult;
 use crate::runtime::coordinator::task_distribution::build_cluster_descriptor;
 use crate::runtime::coordinator::web_server::web_launch;
 use crate::storage::metadata::{
-    loop_delete_cluster_descriptor, loop_read_cluster_descriptor, loop_save_cluster_descriptor,
-    loop_update_application_status, MetadataStorage,
+    loop_read_cluster_descriptor, loop_save_cluster_descriptor, loop_update_application_status,
+    MetadataStorage,
 };
 use crate::utils::date_time::timestamp_str;
 
@@ -138,10 +138,6 @@ where
             self.stop_all_worker_tasks(worker_task_ids);
             info!("stop all workers");
 
-            // clear metadata from storage
-            self.clear_metadata();
-            info!("clear metadata from storage");
-
             if let HeartbeatResult::End = heartbeat_result {
                 return Ok(());
             }
@@ -149,17 +145,25 @@ where
     }
 
     fn prepare_properties(&self) -> Properties {
-        let mut job_properties = Properties::new();
-        job_properties.set_cluster_mode(self.context.cluster_mode);
+        let mut application_properties = Properties::new();
+        application_properties.set_cluster_mode(self.context.cluster_mode);
 
         self.stream_app
-            .prepare_properties(job_properties.borrow_mut());
+            .prepare_properties(application_properties.borrow_mut());
 
-        for (k, v) in job_properties.as_map() {
-            info!("properties key={}, value={}", k, v);
+        let mut keys: Vec<&str> = application_properties
+            .as_map()
+            .keys()
+            .map(|x| x.as_str())
+            .collect();
+        keys.sort();
+
+        for key in keys {
+            let value = application_properties.as_map().get(key).unwrap();
+            info!("properties key={}, value={}", key, value,);
         }
 
-        job_properties
+        application_properties
     }
 
     fn build_metadata(
@@ -179,10 +183,10 @@ where
         loop_save_cluster_descriptor(metadata_storage.borrow_mut(), cluster_descriptor.clone());
     }
 
-    fn clear_metadata(&self) {
-        let mut metadata_storage = MetadataStorage::new(&self.metadata_storage_mode);
-        loop_delete_cluster_descriptor(metadata_storage.borrow_mut());
-    }
+    // fn clear_metadata(&self) {
+    //     let mut metadata_storage = MetadataStorage::new(&self.metadata_storage_mode);
+    //     loop_delete_cluster_descriptor(metadata_storage.borrow_mut());
+    // }
 
     fn build_checkpoint_manager(
         &self,
@@ -265,7 +269,7 @@ where
             let unregister_worker = job_descriptor
                 .worker_managers
                 .iter()
-                .find(|x| x.task_status.ne(&ManagerStatus::Registered));
+                .find(|x| x.status.ne(&ManagerStatus::Registered));
 
             if unregister_worker.is_none() {
                 loop_update_application_status(
